<template>
  <div class="echart" ref="chart"></div>
</template>

<script>
import * as echarts from "echarts"
import { countCountryDimension, countProvinceDimension } from "@/api/screen.js"
export default {
  data() {
    return {
      currentProject: '全球项目'
    }
  },
  mounted() {
    this.initChart()
  },

  methods: {
    async initChart() {
      const res = await countCountryDimension()
      let dataPie = [
        {
          value: 410,
          name: "企业",
        },
        {
          value: 380,
          name: "政府",
        },
        {
          value: 50,
          name: "个人",
        },
        {
          value: 50,
          name: "个人1",
        },
        {
          value: 50,
          name: "个人2",
        },
        {
          value: 50,
          name: "个人3",
        },
        {
          value: 50,
          name: "个人4",
        },
        {
          value: 50,
          name: "个人5",
        },
      ]
      let count = 0
      if (res.code == 200) {
        dataPie = res.result.map(item => {
          return {
            name: item.country,
            value: item.count
          }
        })
      }

      let colorPie = ["#173852", "#0b2036", "#002e49"]
      let colorWrap = [
        "#3087d6",
        "#f6ce54",
        "#4be1ff",
        "#b6e9ff",
        "#18edc9",
        "#6ac5fa",
      ]
      let baseDataPie = [],
        baseDataWrap = []
      let total = 0
      dataPie
        .sort((a, b) => b.value - a.value)
        .forEach(function (val, idx, arr) {
          count += val.value
        })
      for (let i = 0; i < dataPie.length; i++) {
        baseDataWrap.push(
          {
            value: dataPie[i].value,
            name: dataPie[i].name,
            itemStyle: {
              normal: {
                color: colorWrap[i],
                borderWidth: 1,
                borderColor: colorWrap[i],
                shadowBlur: 10,
                shadowColor: "rgba(7, 132, 250, 0.8)",
              },
            },
          },
          {
            value: 0.1,
            name: "",
            itemStyle: {
              normal: {
                color: "transparent",
                borderWidth: 5,
                borderColor: "transparent",
              },
            },
            tooltip: {
              show: false,
            },
          }
        )

        if (i < 3) {
          baseDataPie.push({
            value: dataPie[i].value,
            name: dataPie[i].name,
            itemStyle: {
              normal: {
                borderWidth: 10,
                borderColor: colorPie[i],
              },
            },
          })
        }
      }

      let option = {
        backgroundColor: "transparent",
        title: {
          text: count,
          subtext: "项目总数",
          textStyle: {
            color: "#fff",
            fontSize: 20,
            fontWeight: 400,
            fontFamily: "YouSheBiaoTiHei",
          },
          subtextStyle: {
            align: "center",
            fontSize: 14,
            color: ["#fff"],
            fontWeight: 400,
            fontFamily: "YouSheBiaoTiHei",
          },
          x: "center",
          y: "center",
        },
        grid: {
          left: "1%", // 与容器左侧的距离
          right: "1%", // 与容器右侧的距离
          top: "1%", // 与容器顶部的距离
          bottom: "1%", // 与容器底部的距离
        },
        tooltip: {
          show: true,
          trigger: "item",
        },
        legend: [
          {
            show: false,
            data: ["在线", "维修", "离线", "检修", "抢修", "其他"],
            icon: "vertical",
            right: "5px",
            top: "center",
            orient: "vertical",
            itemGap: 20,
            itemWidth: 15,
            itemHeight: 8,
            formatter: function (name) {
              let target, percent
              for (let i = 0; i < dataPie.length; i++) {
                if (dataPie[i].name === name) {
                  target = dataPie[i].value
                  percent = ((target / total) * 100).toFixed(1)
                }
              }
              let arr = [
                percent + "% " + " {yellow|" + target + "}",
                " {blue|" + name + "}",
              ]
              return arr.join("\n")
            },
            textStyle: {
              lineHeight: 20,
              color: "#f0f4f6",
              align: "right",
              rich: {
                yellow: {
                  color: "#00b5f3",
                  fontWeight: "bold",
                },
                blue: {
                  color: "#4be1ff",
                  align: "right",
                },
              },
            },
          },
        ],
        series: [
          {
            name: "项目数量",
            type: "pie",
            // clockWise: false, //顺时加载
            // hoverAnimation: false, //鼠标移入变大
            center: ["50%", "50%"],
            // radius: ["60%", "70%"],
            radius: [70, 80],
            labelLine: {
              show: true,
            },
            itemStyle: {
              borderWidth: 3,
              // borderColor: "#fff",
            },
            minAngle: 15, //最小角度
            startAngle: 270, //起始角度
            label: {
              // show: false,
              formatter: params => {
                if (params.percent > 10) {
                  return `{b|${params.name}} \n {per|${Math.ceil(
                    (params.value * 100) / count
                  )}%}`
                } else {
                  return `{b|${params.name}}`
                }
              },
              // backgroundColor: "#fff",
              // borderColor: "#aaa",
              // borderWidth: 1,
              // borderRadius: 3,
              // shadowBlur:3,
              // shadowOffsetX: 2,
              // shadowOffsetY: 2,
              // shadowColor: '#999',
              // padding: [0, 7],
              rich: {
                a: {
                  color: "#999",
                  lineHeight: 22,
                  align: "center",
                },
                // abg: {
                //     backgroundColor: '#333',
                //     width: '100%',
                //     align: 'right',
                //     height: 22,
                //     borderRadius: [4, 4, 0, 0]
                // },
                hr: {
                  borderColor: "#aaa",
                  width: "100%",
                  borderWidth: 0.5,
                  height: 0,
                },
                b: {
                  fontSize: 14,
                  lineHeight: 14,
                  color: '#fff'
                },
                per: {
                  color: "#eee",
                  backgroundColor: "#334455",
                  padding: [2, 4],
                  borderRadius: 2,
                },
              },
            },

            data: baseDataWrap,
          },
        ],
      }
      const chart = echarts.init(this.$refs.chart)

      chart.setOption(option)
      window.addEventListener("resize", function () {
        chart.resize()
      })
    },

  },
}
</script>

<style lang="scss" scoped>
.echart {
  width: 100%;
  height: 85%;
}
</style>
